#
# spec file for package open-isns
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1600
%bcond_with slp
%else
%bcond_without slp
%endif

Name:           open-isns
VCS: https://src.suse.de/SLFO-pool/open-isns#4c803f961d74dc98005db705c9eeaf8d361a5e4fbb232cc09b5324ef80e9affa
Summary:        Partial Implementation of iSNS iSCSI registration
License:        LGPL-2.1-or-later
Group:          System/Kernel
Version:        0.102
Release:        160000.1.24
Source:         %{name}-%{version}.tar.xz
Patch1:         Quiet-a-commpiler-warning.patch
URL:            https://github.com/open-iscsi/%{name}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  glibc-devel
BuildRequires:  make
BuildRequires:  meson >= 0.55.0
%if %{with slp}
BuildRequires:  openslp-devel
%endif
BuildRequires:  openssl-devel
BuildRequires:  systemd-rpm-macros
%{?systemd_requires}
Requires:       coreutils
Recommends:     open-iscsi

%description
This is a partial implementation of the iSNS protocol (see below),
which supplies directory services for iSCSI initiators and targets.

The iSNS protocol is specified in
[RFC 4171](http://tools.ietf.org/html/rfc4171) and its purpose is to
make easier to discover, manage, and configure iSCSI devices. With
iSNS, iSCSI targets can be registered to a central iSNS server and
initiators can be configured to discover the targets by asking the
iSNS server.

%package devel
Summary:        Development files for open-isns
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
Files to develop an application using the open-isns library.

%prep
%autosetup -p1

%build
%global _lto_cflags %{?_lto_cflags} -ffat-lto-objects
%meson --default-library=both \
%if %{with slp}
       -Dslp=enabled
%else
       -Dslp=disabled
%endif
%meson_build

%install
%meson_install
ln -sf /usr/sbin/service %{buildroot}/usr/sbin/rcisnsd

%post
%{run_ldconfig}
%{service_add_post isnsd.socket isnsd.service}

%postun
%{service_del_postun isnsd.socket isnsd.service}
%{run_ldconfig}

%pre
%{service_add_pre isnsd.socket isnsd.service}

%preun
%{service_del_preun isnsd.socket isnsd.service}

%post devel -p %{run_ldconfig}
%postun devel -p %{run_ldconfig}

%files
%defattr(-,root,root)
%{_sbindir}/isnsd
%{_sbindir}/isnsadm
%{_sbindir}/isnsdd
%dir %{_sysconfdir}/isns
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/isns/isnsd.conf
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/isns/isnsadm.conf
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/isns/isnsdd.conf
%{_sbindir}/rcisnsd
%license COPYING
%doc HACKING README TODO
%doc %{_mandir}/man8/isnsd.8%{?ext_man}
%doc %{_mandir}/man8/isnsadm.8%{?ext_man}
%doc %{_mandir}/man8/isnsdd.8%{?ext_man}
%doc %{_mandir}/man5/isns_config.5%{?ext_man}
%{_unitdir}/isnsd.service
%{_unitdir}/isnsd.socket
%{_libdir}/libisns.so.0

%files devel
%defattr(-,root,root)
%dir %{_includedir}/libisns
%{_includedir}/libisns/attrs.h
%{_includedir}/libisns/buffer.h
%{_includedir}/libisns/isns.h
%{_includedir}/libisns/isns-proto.h
%{_includedir}/libisns/message.h
%{_includedir}/libisns/paths.h
%{_includedir}/libisns/source.h
%{_includedir}/libisns/types.h
%{_includedir}/libisns/util.h
%{_libdir}/libisns.a
%{_libdir}/libisns.so
%{_libdir}/pkgconfig/libisns.pc

%changelog
* Tue Sep  5 2023 kukuk@suse.com
- Disable SLP by default for Factory and ALP (bsc#1214884)
* Thu Sep  8 2022 lduncan@suse.com
- Update to version 0.102:
  * Preparing for version v0.102
  * meson: just specify subdir for header-file install.
  * build: only specify version in one place
  * Fix two compiler warnings in slp.c
  * meson: update README
  * meson: small option usage cleanup
  * meson: several updates based on review
  * meson: fix error building shared lib with version
  * meson: convert some args to 'features'
  * meson: update README with meson info
  * Add a decprecation warning to configure script.
  * meson: Add ability to disable static library build
  * meson builds now working
  * git: ignore all shared library files
  * build: Remove these two files, no longer used
  * Add a package config file for libisns.a
  * isnsd: socket: Make sure to create IPv6 socket default
  * isnsadm: Fix unparse command line options "-V" and "-r"
  * Typo: s/overried/override/
  * Removed bash-specific function definitions.
  Also, added patch to quiet compiler (soon upstream):
  * Quiet-a-commpiler-warning.patch
  This changes the SPEC file to use the new meson build system,
  supported in open-isns starting with version 0.102, instead of
  autoconf/make.
  Changes in the code:
  * no longer deliver isnsetup script or man page (development only)
  * now deliver a package config file for the library
  * now deliver both the static library and a shared library
* Mon Feb  1 2021 lduncan@suse.com
- Update to version 0.101:
  * Updated ChangeLog for version v0.101
  * Preparing for version 0.101
  * Fix parsing of GetNextRsp
  * Added TODO to test "isnsd --init"
  * Add man page for isnssetup.
  * Fix broken server authentication initialization.
  * Update version string to "0.100".
  * Added a TODO: 'make depend' not worrking
  * libisns: remove sighold and sigrelse
  * fix compilation without deprecated OpenSSL APIs
  * socket.c: include poll.h instead of sys/poll.h for POSIX compatibility
  * Fix 586 compile issue and remove -Werror
  * Do not ignore write() return value.
  * Fix compiler issue when not in security mode
  * Ignore common build files
  This removed the need for open-isns-updates.diff.bz2 (for now), since
  those commits are in version v0.101.
* Thu Dec 10 2020 lduncan@suse.com
- Removed isns.xml, as firewalld already supplies this file.
  Note that SuSEFirewall2 is also no longer supported, which
  obviates the need for the file "open-isns-firewall.service",
  which was used in SLES but not in openSUSE.
* Mon Dec  7 2020 lduncan@suse.com
- Added file isns.xml for firewalld, updated SPEC file for it,
  since SuSEfirewall2 is deprecated.
* Fri Dec  4 2020 lduncan@suse.com
- Updated SPEC file to Recommend open-iscsi
* Fri Dec  4 2020 lduncan@suse.com
- Updated to latest upstream, including:
  * Add man page for isnssetup.
  * Fix broken server authentication initialization.
  * Update version string to "0.100".
  * Added a TODO: 'make depend' not worrking
  * libisns: remove sighold and sigrelse
  * fix compilation without deprecated OpenSSL APIs
  * socket.c: include poll.h instead of sys/poll.h for POSIX compatibility
  * Fix 586 compile issue and remove -Werror
  * Do not ignore write() return value.
  * Fix compiler issue when n
  Which updates open-isns-updates.diff.bz2, and removes the
  no-longer-needed patch open-isns-fix-586-time.patch.
  Also, security will be enabled/configured with this update.
* Fri Jan 31 2020 lduncan@suse.com
- Update to version 0.100:
  * Updated ChangeLog with latest fixes
  * Create and use pythong unittest framework
  * Ignore SO lib
  * Handle restarting test harness server correctly
  * Fix mdebug.c so it compiles when enabled.
  * Running make twice should not rebuild everything
  * Change isns_portal_string() to use static mem
  * Adding python compiled files
  * fixed issues with old openssl usage
  * Added debugging, moved .cvsignore to .gitignore
  * Preparing for version v0.100
  * Fix problem with parsing IPv6 Addresses with brakcets.
  * General cleanup for the compiler.
  * Travis-CI and Coverity Scan setup
  * openssl: handle newer version with ifdefs
  * Remove old compiler option, and add "-Werror".
  * Change isns_portal_string() to return allocated string.
  * add tags to ignored list of files
  * Fix compiler complaint about possible alignment issue
  Replacing open-isns-0.99.tar.xz with open-isns-0.100.tar.xz.
  Also, added latest (not yet tagged) fixes from upstream,
  adding patch, and add in a 586-fix, adding:
  * open-isns-updates.diff.bz2, and
  * open-isns-fix-586-time.patch
* Mon Oct 28 2019 lduncan@suse.com
- Updated SPEC file %%_lto_cflags definition so that it does not
  cause recursion.
* Wed Oct 23 2019 mliska@suse.cz
- Move back "%%global _lto_cflags ..." line as it's needed
  for the following error:
  E: lto-no-text-in-archive (Badness: 10000) /usr/lib64/libisns.a.
  The recursion in macro was caused by fact that the macro was not
  defined for some time in prjconfig.
* Fri Oct  4 2019 lduncan@suse.com
- Had to address build issue in OBS, resulting in this package not
  building, with message (folding done by me):
  + exec rpmbuild -ba --define '_srcdefattr (-,root,root)' --nosignature \
  - -define '_build_create_debug 1' \
  - -define 'disturl obs://build.opensuse.org/Base:System/openSUSE_Factory/93a92c971e76cbf08ebb7afd9a4de7be-open-isns' \
  /home/abuild/rpmbuild/SOURCES/open-isns.spec
    error: /home/abuild/rpmbuild/SOURCES/open-isns.spec: \
  line 63: Too many levels of recursion in macro expansion. It is likely caused by recursive macro declaration.
  Line 63 was the "%%configure" call, but I believe recursion is caused
  by redefinition of _lto_cflags.  To fix this, I reverted the
  "Use FAT LTO ..." commit, removing the "%%global _lto_cflags ..." line.
* Wed Jul 24 2019 matthias.gerstner@suse.com
- removal of SuSEfirewall2 service, since SuSEfirewall2 has been replaced by
  firewalld, see [1].
  [1]: https://lists.opensuse.org/opensuse-factory/2019-01/msg00490.html
* Fri Apr 26 2019 mliska@suse.cz
- Use FAT LTO objects in order to provide proper static library (boo#1133271).
* Thu Oct 25 2018 lduncan@suse.com
- Update to version 0.99:
  * Update version to v0.99, and fill in ChangeLog
  * util.h: endian.h is available on musl on linux
  * Added README info about testing without security.
  * Support building/testing for with-security=no
  * Define 'free()' for isns_free()
  * Fix error with SCN Deregister when not registered.
  * Cleanup: reformat and add some print statements.
  * Fix error with type of node in GetNext test.
  * Add testing information to the README.
  Which replaced open-isns-0.98.tar.gz with open-isns-0.99.tar.xz
  Also added the _service* files to manage updates.
* Thu Aug 31 2017 lduncan@suse.com
- Update from version 0.97 to 0.98, which includes some
  testing and openssl fixes, updating the SPEC file and
  replacing the release tarball (bsc#1056696)
* Tue Aug  8 2017 jengelh@inai.de
- Fix RPM groups. Replace %%__-type macro indirections and
  old $RPM shell variables.
* Wed Nov  2 2016 lduncan@suse.com
- Updated to version 0.97, replacing main tarball
* Thu Jun 23 2016 lduncan@suse.com
- Updated to version 0.96, replacing main tarball, and
  removing both patches:
  D    open-isns-Update-GPL-license-information.patch
  D    open-isns-Install-isns_config.5.patch
* Fri Dec 18 2015 lduncan@suse.com
- Updated SPEC file dependencies so early install works
  (bsc#958567)
* Wed Dec 16 2015 lduncan@suse.com
- Updated COPYING and README files for updated GNU license, adding:
  open-isns-Update-GPL-license-information.patch
* Wed Dec  9 2015 lduncan@suse.com
- Updated spec file to install hdrs and library file
* Wed Dec  9 2015 lduncan@suse.com
- Also must install isns_config.5, added upstream patch:
  open-isns-open-isns-Install-isns_config.5.patch
* Tue Dec  8 2015 lduncan@suse.com
- Initial creation of Build Service project, using version
  0.95 of open-isns from github.com/gonzoleeman/open-isns
